"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getConfig = void 0;
const errors_1 = require("./errors");
function getConfig() {
    return __awaiter(this, void 0, void 0, function* () {
        const { allowIntrospection, allowedOrigins, apiPort, cacheEnabled, genesisFileByron, genesisFileShelley, hasuraUri, poolMetadataProxy, prometheusMetrics, queryDepthLimit, tracing, whitelistPath } = filterAndTypecastEnvs(process.env);
        if (!hasuraUri && !genesisFileShelley) {
            throw new errors_1.MissingConfig('You have not provided configuration to load an API segment. Either set HASURA_URI or GENESIS_FILE_SHELLEY');
        }
        if (prometheusMetrics && process.env.TRACING === 'false') {
            throw new errors_1.TracingRequired('Prometheus');
        }
        if (whitelistPath && allowIntrospection) {
            throw new errors_1.IntrospectionNotPermitted('whitelist');
        }
        return {
            allowIntrospection,
            allowedOrigins: allowedOrigins || true,
            apiPort: apiPort || 3100,
            cacheEnabled: cacheEnabled || false,
            genesisFileByron,
            genesisFileShelley,
            hasuraUri,
            poolMetadataProxy,
            prometheusMetrics,
            queryDepthLimit: queryDepthLimit || 10,
            tracing,
            whitelistPath
        };
    });
}
exports.getConfig = getConfig;
function filterAndTypecastEnvs(env) {
    const { ALLOW_INTROSPECTION, ALLOWED_ORIGINS, API_PORT, CACHE_ENABLED, GENESIS_FILE_BYRON, GENESIS_FILE_SHELLEY, HASURA_URI, POOL_METADATA_PROXY, PROMETHEUS_METRICS, QUERY_DEPTH_LIMIT, TRACING, WHITELIST_PATH } = env;
    return {
        allowIntrospection: ALLOW_INTROSPECTION === 'true' ? true : undefined,
        allowedOrigins: ALLOWED_ORIGINS,
        apiPort: Number(API_PORT),
        cacheEnabled: CACHE_ENABLED === 'true' ? true : undefined,
        genesisFileByron: GENESIS_FILE_BYRON,
        genesisFileShelley: GENESIS_FILE_SHELLEY,
        hasuraUri: HASURA_URI,
        poolMetadataProxy: POOL_METADATA_PROXY,
        prometheusMetrics: PROMETHEUS_METRICS === 'true' ? true : undefined,
        queryDepthLimit: Number(QUERY_DEPTH_LIMIT),
        tracing: TRACING === 'true' ? true : undefined,
        whitelistPath: WHITELIST_PATH
    };
}
//# sourceMappingURL=config.js.map