"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __exportStar = (this && this.__exportStar) || function(m, exports) {
    for (var p in m) if (p !== "default" && !exports.hasOwnProperty(p)) __createBinding(exports, m, p);
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.apolloServerPlugins = void 0;
const apolloServerPlugins = __importStar(require("./apollo_server_plugins"));
exports.apolloServerPlugins = apolloServerPlugins;
const express_1 = __importDefault(require("express"));
const fs_1 = __importDefault(require("fs"));
const config_1 = require("./config");
const Server_1 = require("./Server");
const graphql_depth_limit_1 = __importDefault(require("graphql-depth-limit"));
const merge_1 = require("@graphql-tools/merge");
const api_cardano_db_hasura_1 = require("@cardano-graphql/api-cardano-db-hasura");
const api_genesis_1 = require("@cardano-graphql/api-genesis");
__exportStar(require("./config"), exports);
const { prometheusMetricsPlugin, whitelistPlugin } = apolloServerPlugins;
function boot() {
    return __awaiter(this, void 0, void 0, function* () {
        const config = yield config_1.getConfig();
        const schemas = [];
        const validationRules = [];
        const plugins = [];
        const app = express_1.default();
        if (config.genesisFileByron !== undefined || config.genesisFileShelley !== undefined) {
            schemas.push(api_genesis_1.buildSchema(Object.assign(Object.assign({}, config.genesisFileByron !== undefined ? { byron: require(config.genesisFileByron) } : {}), config.genesisFileShelley !== undefined ? { shelley: require(config.genesisFileShelley) } : {})));
        }
        if (config.hasuraUri !== undefined) {
            const db = new api_cardano_db_hasura_1.Db(config.hasuraUri);
            yield db.init();
            schemas.push(yield api_cardano_db_hasura_1.buildSchema(config.hasuraUri, db));
        }
        if (config.prometheusMetrics) {
            plugins.push(prometheusMetricsPlugin(app));
        }
        if (config.whitelistPath) {
            const whitelist = JSON.parse(fs_1.default.readFileSync(config.whitelistPath, 'utf8'));
            plugins.push(whitelistPlugin(whitelist));
        }
        if (config.queryDepthLimit) {
            validationRules.push(graphql_depth_limit_1.default(config.queryDepthLimit));
        }
        const server = Server_1.Server(app, {
            cacheControl: config.cacheEnabled ? { defaultMaxAge: 20 } : undefined,
            introspection: config.allowIntrospection,
            playground: config.allowIntrospection,
            plugins,
            validationRules,
            schema: merge_1.mergeSchemas({
                schemas
            })
        }, {
            origin: config.allowedOrigins
        });
        try {
            app.listen({ port: config.apiPort }, () => {
                const serverUri = `http://localhost:${config.apiPort}`;
                console.log(`GraphQL HTTP server at ${serverUri}${server.graphqlPath}`);
                if (process.env.NODE_ENV !== 'production' && config.whitelistPath) {
                    console.warn('As a whitelist is in effect, the GraphQL Playground is available, but will not allow schema exploration');
                }
                if (config.prometheusMetrics) {
                    console.log(`Prometheus metrics at ${serverUri}/metrics`);
                }
            });
        }
        catch (error) {
            console.error(error.message);
        }
    });
}
boot();
//# sourceMappingURL=index.js.map